pair_polychor: Polychoric correlation
Description
Calculates Polychoric correlation using for every factor variable pair in a dataset.
Usage
pair_polychor(d, handle.na = TRUE, ...)
Value
A tibble of class pairwise with polychoric correlation for factor pairs,
or NULL if there are not at least two factor variables
Arguments
- d
A dataframe
- handle.na
ignored. Pairwise complete observations are used automatically.
- ...
other arguments
Details
The polychoric correlation is calculated using the polychor function from the
polycor package, and assumes factor levels are in the given order. NAs are automatically handled by pairwise omit.