pair_polyserial: Polyserial correlation
Description
Calculates Polyserial correlation using for every factor-numeric variable pair in a dataset.
Usage
pair_polyserial(d, handle.na = TRUE, ...)
Value
A tibble of class pairwise with polyserial correlation for factor-numeric pairs,
or NULL if there are not at least one such pair.
Arguments
- d
A dataframe
- handle.na
ignored. Pairwise complete observations are used automatically.
- ...
other arguments
Details
The polyserial correlation is calculated using the polyserial function from the
polycor package, and assumes factor levels are in the given order. NAs are automatically handled by pairwise omit.