pairwise_scoresGives a list specifying the function to be used for two numeric (nn) variables, two factors (ff), two ordinals (oo) and for a factor-numeric pair (fn).
pair_control(
nn = "pair_cor",
oo = "pair_polychor",
ff = "pair_cancor",
fn = "pair_cancor",
nnargs = NULL,
ooargs = NULL,
ffargs = NULL,
fnargs = NULL
)list
function for numeric pairs of variables, should return object of class pairwise. Use NULL to ignore numeric pairs.
function for ordered factor pairs of variables, should return object of class pairwise. Use NULL to ignore ordered factor pairs.
function for factor pairs of variables (not ordered), should return object of class pairwise. Use NULL to ignore factor-factor pairs.
function for factor-numeric pairs of variables, should return object of class pairwise. Use NULL to ignore factor-numeric pairs.
other arguments for the nn function
other arguments for the oo function
other arguments for the ff function
other arguments for the fn function